ClaudeProjector

Struct ClaudeProjector 

pub struct ClaudeProjector;
Project a ConversationView into a Claude Conversation.

Maps the provider-agnostic view back into Claude’s JSONL wire format. Assistant turns with tool uses will produce a separate tool-result user entry after each assistant entry (one entry per assistant turn that has tool uses with results).

Example

use toolpath_claude::project::ClaudeProjector;
use toolpath_convo::{ConversationView, ConversationProjector};

let view = ConversationView {
    id: "my-session".to_string(),
    started_at: None,
    last_activity: None,
    turns: vec![],
    total_usage: None,
    provider_id: None,
    files_changed: vec![],
    session_ids: vec![],
    events: vec![],
};

let projector = ClaudeProjector;
let convo = projector.project(&view).unwrap();
assert_eq!(convo.session_id, "my-session");