Structs
- Cache
Creation - Conversation
- Conversation
Entry - Conversation
Metadata - History
Entry - Message
- Tool
Result Part - Tool
Result Ref - A reference to a tool result entry within a content part.
- Tool
UseRef - A reference to a tool use entry within a content part.
- Usage