Module types

Module types 

Structs

CacheCreation
Conversation
ConversationEntry
ConversationMetadata
HistoryEntry
Message
ToolResultPart
ToolResultRef
A reference to a tool result entry within a content part.
ToolUseRef
A reference to a tool use entry within a content part.
Usage

Enums

ContentPart
MessageContent
MessageRole
ToolResultContent